@@ -1,7 +1,7 @@
 """
 Type annotations for redshift-data service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/literals/)
 
 Usage::
 
@@ -164,6 +164,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
