@@ -62,18 +62,32 @@ __all__ = (
     "TableMemberTypeDef",
 )
 
-BatchExecuteStatementInputRequestTypeDef = TypedDict(
-    "BatchExecuteStatementInputRequestTypeDef",
+_RequiredBatchExecuteStatementInputRequestTypeDef = TypedDict(
+    "_RequiredBatchExecuteStatementInputRequestTypeDef",
     {
         "Database": str,
         "Sqls": Sequence[str],
-        "ClusterIdentifier": NotRequired[str],
-        "DbUser": NotRequired[str],
-        "SecretArn": NotRequired[str],
-        "StatementName": NotRequired[str],
-        "WithEvent": NotRequired[bool],
     },
 )
+_OptionalBatchExecuteStatementInputRequestTypeDef = TypedDict(
+    "_OptionalBatchExecuteStatementInputRequestTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "DbUser": str,
+        "SecretArn": str,
+        "StatementName": str,
+        "WithEvent": bool,
+    },
+    total=False,
+)
+
+
+class BatchExecuteStatementInputRequestTypeDef(
+    _RequiredBatchExecuteStatementInputRequestTypeDef,
+    _OptionalBatchExecuteStatementInputRequestTypeDef,
+):
+    pass
+
 
 BatchExecuteStatementOutputTypeDef = TypedDict(
     "BatchExecuteStatementOutputTypeDef",
@@ -106,20 +120,21 @@ CancelStatementResponseTypeDef = TypedDict(
 ColumnMetadataTypeDef = TypedDict(
     "ColumnMetadataTypeDef",
     {
-        "columnDefault": NotRequired[str],
-        "isCaseSensitive": NotRequired[bool],
-        "isCurrency": NotRequired[bool],
-        "isSigned": NotRequired[bool],
-        "label": NotRequired[str],
-        "length": NotRequired[int],
-        "name": NotRequired[str],
-        "nullable": NotRequired[int],
-        "precision": NotRequired[int],
-        "scale": NotRequired[int],
-        "schemaName": NotRequired[str],
-        "tableName": NotRequired[str],
-        "typeName": NotRequired[str],
+        "columnDefault": str,
+        "isCaseSensitive": bool,
+        "isCurrency": bool,
+        "isSigned": bool,
+        "label": str,
+        "length": int,
+        "name": str,
+        "nullable": int,
+        "precision": int,
+        "scale": int,
+        "schemaName": str,
+        "tableName": str,
+        "typeName": str,
     },
+    total=False,
 )
 
 DescribeStatementRequestRequestTypeDef = TypedDict(
@@ -154,34 +169,61 @@ DescribeStatementResponseTypeDef = TypedDict(
     },
 )
 
-DescribeTableRequestDescribeTablePaginateTypeDef = TypedDict(
-    "DescribeTableRequestDescribeTablePaginateTypeDef",
+_RequiredDescribeTableRequestDescribeTablePaginateTypeDef = TypedDict(
+    "_RequiredDescribeTableRequestDescribeTablePaginateTypeDef",
     {
         "Database": str,
-        "ClusterIdentifier": NotRequired[str],
-        "ConnectedDatabase": NotRequired[str],
-        "DbUser": NotRequired[str],
-        "Schema": NotRequired[str],
-        "SecretArn": NotRequired[str],
-        "Table": NotRequired[str],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalDescribeTableRequestDescribeTablePaginateTypeDef = TypedDict(
+    "_OptionalDescribeTableRequestDescribeTablePaginateTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "Schema": str,
+        "SecretArn": str,
+        "Table": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-DescribeTableRequestRequestTypeDef = TypedDict(
-    "DescribeTableRequestRequestTypeDef",
+
+class DescribeTableRequestDescribeTablePaginateTypeDef(
+    _RequiredDescribeTableRequestDescribeTablePaginateTypeDef,
+    _OptionalDescribeTableRequestDescribeTablePaginateTypeDef,
+):
+    pass
+
+
+_RequiredDescribeTableRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeTableRequestRequestTypeDef",
     {
         "Database": str,
-        "ClusterIdentifier": NotRequired[str],
-        "ConnectedDatabase": NotRequired[str],
-        "DbUser": NotRequired[str],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
-        "Schema": NotRequired[str],
-        "SecretArn": NotRequired[str],
-        "Table": NotRequired[str],
     },
 )
+_OptionalDescribeTableRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeTableRequestRequestTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "MaxResults": int,
+        "NextToken": str,
+        "Schema": str,
+        "SecretArn": str,
+        "Table": str,
+    },
+    total=False,
+)
+
+
+class DescribeTableRequestRequestTypeDef(
+    _RequiredDescribeTableRequestRequestTypeDef, _OptionalDescribeTableRequestRequestTypeDef
+):
+    pass
+
 
 DescribeTableResponseTypeDef = TypedDict(
     "DescribeTableResponseTypeDef",
@@ -193,19 +235,32 @@ DescribeTableResponseTypeDef = TypedDict(
     },
 )
 
-ExecuteStatementInputRequestTypeDef = TypedDict(
-    "ExecuteStatementInputRequestTypeDef",
+_RequiredExecuteStatementInputRequestTypeDef = TypedDict(
+    "_RequiredExecuteStatementInputRequestTypeDef",
     {
         "Database": str,
         "Sql": str,
-        "ClusterIdentifier": NotRequired[str],
-        "DbUser": NotRequired[str],
-        "Parameters": NotRequired[Sequence["SqlParameterTypeDef"]],
-        "SecretArn": NotRequired[str],
-        "StatementName": NotRequired[str],
-        "WithEvent": NotRequired[bool],
     },
 )
+_OptionalExecuteStatementInputRequestTypeDef = TypedDict(
+    "_OptionalExecuteStatementInputRequestTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "DbUser": str,
+        "Parameters": Sequence["SqlParameterTypeDef"],
+        "SecretArn": str,
+        "StatementName": str,
+        "WithEvent": bool,
+    },
+    total=False,
+)
+
+
+class ExecuteStatementInputRequestTypeDef(
+    _RequiredExecuteStatementInputRequestTypeDef, _OptionalExecuteStatementInputRequestTypeDef
+):
+    pass
+
 
 ExecuteStatementOutputTypeDef = TypedDict(
     "ExecuteStatementOutputTypeDef",
@@ -223,30 +278,59 @@ ExecuteStatementOutputTypeDef = TypedDict(
 FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
-        "blobValue": NotRequired[bytes],
-        "booleanValue": NotRequired[bool],
-        "doubleValue": NotRequired[float],
-        "isNull": NotRequired[bool],
-        "longValue": NotRequired[int],
-        "stringValue": NotRequired[str],
+        "blobValue": bytes,
+        "booleanValue": bool,
+        "doubleValue": float,
+        "isNull": bool,
+        "longValue": int,
+        "stringValue": str,
     },
+    total=False,
 )
 
-GetStatementResultRequestGetStatementResultPaginateTypeDef = TypedDict(
-    "GetStatementResultRequestGetStatementResultPaginateTypeDef",
+_RequiredGetStatementResultRequestGetStatementResultPaginateTypeDef = TypedDict(
+    "_RequiredGetStatementResultRequestGetStatementResultPaginateTypeDef",
     {
         "Id": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalGetStatementResultRequestGetStatementResultPaginateTypeDef = TypedDict(
+    "_OptionalGetStatementResultRequestGetStatementResultPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-GetStatementResultRequestRequestTypeDef = TypedDict(
-    "GetStatementResultRequestRequestTypeDef",
+
+class GetStatementResultRequestGetStatementResultPaginateTypeDef(
+    _RequiredGetStatementResultRequestGetStatementResultPaginateTypeDef,
+    _OptionalGetStatementResultRequestGetStatementResultPaginateTypeDef,
+):
+    pass
+
+
+_RequiredGetStatementResultRequestRequestTypeDef = TypedDict(
+    "_RequiredGetStatementResultRequestRequestTypeDef",
     {
         "Id": str,
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalGetStatementResultRequestRequestTypeDef = TypedDict(
+    "_OptionalGetStatementResultRequestRequestTypeDef",
+    {
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class GetStatementResultRequestRequestTypeDef(
+    _RequiredGetStatementResultRequestRequestTypeDef,
+    _OptionalGetStatementResultRequestRequestTypeDef,
+):
+    pass
+
 
 GetStatementResultResponseTypeDef = TypedDict(
     "GetStatementResultResponseTypeDef",
@@ -259,28 +343,55 @@ GetStatementResultResponseTypeDef = TypedDict(
     },
 )
 
-ListDatabasesRequestListDatabasesPaginateTypeDef = TypedDict(
-    "ListDatabasesRequestListDatabasesPaginateTypeDef",
+_RequiredListDatabasesRequestListDatabasesPaginateTypeDef = TypedDict(
+    "_RequiredListDatabasesRequestListDatabasesPaginateTypeDef",
     {
         "Database": str,
-        "ClusterIdentifier": NotRequired[str],
-        "DbUser": NotRequired[str],
-        "SecretArn": NotRequired[str],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListDatabasesRequestListDatabasesPaginateTypeDef = TypedDict(
+    "_OptionalListDatabasesRequestListDatabasesPaginateTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "DbUser": str,
+        "SecretArn": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListDatabasesRequestRequestTypeDef = TypedDict(
-    "ListDatabasesRequestRequestTypeDef",
+
+class ListDatabasesRequestListDatabasesPaginateTypeDef(
+    _RequiredListDatabasesRequestListDatabasesPaginateTypeDef,
+    _OptionalListDatabasesRequestListDatabasesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListDatabasesRequestRequestTypeDef = TypedDict(
+    "_RequiredListDatabasesRequestRequestTypeDef",
     {
         "Database": str,
-        "ClusterIdentifier": NotRequired[str],
-        "DbUser": NotRequired[str],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
-        "SecretArn": NotRequired[str],
     },
 )
+_OptionalListDatabasesRequestRequestTypeDef = TypedDict(
+    "_OptionalListDatabasesRequestRequestTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "DbUser": str,
+        "MaxResults": int,
+        "NextToken": str,
+        "SecretArn": str,
+    },
+    total=False,
+)
+
+
+class ListDatabasesRequestRequestTypeDef(
+    _RequiredListDatabasesRequestRequestTypeDef, _OptionalListDatabasesRequestRequestTypeDef
+):
+    pass
+
 
 ListDatabasesResponseTypeDef = TypedDict(
     "ListDatabasesResponseTypeDef",
@@ -291,32 +402,59 @@ ListDatabasesResponseTypeDef = TypedDict(
     },
 )
 
-ListSchemasRequestListSchemasPaginateTypeDef = TypedDict(
-    "ListSchemasRequestListSchemasPaginateTypeDef",
+_RequiredListSchemasRequestListSchemasPaginateTypeDef = TypedDict(
+    "_RequiredListSchemasRequestListSchemasPaginateTypeDef",
     {
         "Database": str,
-        "ClusterIdentifier": NotRequired[str],
-        "ConnectedDatabase": NotRequired[str],
-        "DbUser": NotRequired[str],
-        "SchemaPattern": NotRequired[str],
-        "SecretArn": NotRequired[str],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListSchemasRequestListSchemasPaginateTypeDef = TypedDict(
+    "_OptionalListSchemasRequestListSchemasPaginateTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "SchemaPattern": str,
+        "SecretArn": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListSchemasRequestRequestTypeDef = TypedDict(
-    "ListSchemasRequestRequestTypeDef",
+
+class ListSchemasRequestListSchemasPaginateTypeDef(
+    _RequiredListSchemasRequestListSchemasPaginateTypeDef,
+    _OptionalListSchemasRequestListSchemasPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListSchemasRequestRequestTypeDef = TypedDict(
+    "_RequiredListSchemasRequestRequestTypeDef",
     {
         "Database": str,
-        "ClusterIdentifier": NotRequired[str],
-        "ConnectedDatabase": NotRequired[str],
-        "DbUser": NotRequired[str],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
-        "SchemaPattern": NotRequired[str],
-        "SecretArn": NotRequired[str],
     },
 )
+_OptionalListSchemasRequestRequestTypeDef = TypedDict(
+    "_OptionalListSchemasRequestRequestTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "MaxResults": int,
+        "NextToken": str,
+        "SchemaPattern": str,
+        "SecretArn": str,
+    },
+    total=False,
+)
+
+
+class ListSchemasRequestRequestTypeDef(
+    _RequiredListSchemasRequestRequestTypeDef, _OptionalListSchemasRequestRequestTypeDef
+):
+    pass
+
 
 ListSchemasResponseTypeDef = TypedDict(
     "ListSchemasResponseTypeDef",
@@ -330,22 +468,24 @@ ListSchemasResponseTypeDef = TypedDict(
 ListStatementsRequestListStatementsPaginateTypeDef = TypedDict(
     "ListStatementsRequestListStatementsPaginateTypeDef",
     {
-        "RoleLevel": NotRequired[bool],
-        "StatementName": NotRequired[str],
-        "Status": NotRequired[StatusStringType],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "RoleLevel": bool,
+        "StatementName": str,
+        "Status": StatusStringType,
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListStatementsRequestRequestTypeDef = TypedDict(
     "ListStatementsRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
-        "RoleLevel": NotRequired[bool],
-        "StatementName": NotRequired[str],
-        "Status": NotRequired[StatusStringType],
+        "MaxResults": int,
+        "NextToken": str,
+        "RoleLevel": bool,
+        "StatementName": str,
+        "Status": StatusStringType,
     },
+    total=False,
 )
 
 ListStatementsResponseTypeDef = TypedDict(
@@ -357,34 +497,61 @@ ListStatementsResponseTypeDef = TypedDict(
     },
 )
 
-ListTablesRequestListTablesPaginateTypeDef = TypedDict(
-    "ListTablesRequestListTablesPaginateTypeDef",
+_RequiredListTablesRequestListTablesPaginateTypeDef = TypedDict(
+    "_RequiredListTablesRequestListTablesPaginateTypeDef",
     {
         "Database": str,
-        "ClusterIdentifier": NotRequired[str],
-        "ConnectedDatabase": NotRequired[str],
-        "DbUser": NotRequired[str],
-        "SchemaPattern": NotRequired[str],
-        "SecretArn": NotRequired[str],
-        "TablePattern": NotRequired[str],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListTablesRequestListTablesPaginateTypeDef = TypedDict(
+    "_OptionalListTablesRequestListTablesPaginateTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "SchemaPattern": str,
+        "SecretArn": str,
+        "TablePattern": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListTablesRequestRequestTypeDef = TypedDict(
-    "ListTablesRequestRequestTypeDef",
+
+class ListTablesRequestListTablesPaginateTypeDef(
+    _RequiredListTablesRequestListTablesPaginateTypeDef,
+    _OptionalListTablesRequestListTablesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListTablesRequestRequestTypeDef = TypedDict(
+    "_RequiredListTablesRequestRequestTypeDef",
     {
         "Database": str,
-        "ClusterIdentifier": NotRequired[str],
-        "ConnectedDatabase": NotRequired[str],
-        "DbUser": NotRequired[str],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
-        "SchemaPattern": NotRequired[str],
-        "SecretArn": NotRequired[str],
-        "TablePattern": NotRequired[str],
     },
 )
+_OptionalListTablesRequestRequestTypeDef = TypedDict(
+    "_OptionalListTablesRequestRequestTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "MaxResults": int,
+        "NextToken": str,
+        "SchemaPattern": str,
+        "SecretArn": str,
+        "TablePattern": str,
+    },
+    total=False,
+)
+
+
+class ListTablesRequestRequestTypeDef(
+    _RequiredListTablesRequestRequestTypeDef, _OptionalListTablesRequestRequestTypeDef
+):
+    pass
+
 
 ListTablesResponseTypeDef = TypedDict(
     "ListTablesResponseTypeDef",
@@ -398,10 +565,11 @@ ListTablesResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -423,44 +591,67 @@ SqlParameterTypeDef = TypedDict(
     },
 )
 
-StatementDataTypeDef = TypedDict(
-    "StatementDataTypeDef",
+_RequiredStatementDataTypeDef = TypedDict(
+    "_RequiredStatementDataTypeDef",
     {
         "Id": str,
-        "CreatedAt": NotRequired[datetime],
-        "IsBatchStatement": NotRequired[bool],
-        "QueryParameters": NotRequired[List["SqlParameterTypeDef"]],
-        "QueryString": NotRequired[str],
-        "QueryStrings": NotRequired[List[str]],
-        "SecretArn": NotRequired[str],
-        "StatementName": NotRequired[str],
-        "Status": NotRequired[StatusStringType],
-        "UpdatedAt": NotRequired[datetime],
     },
 )
+_OptionalStatementDataTypeDef = TypedDict(
+    "_OptionalStatementDataTypeDef",
+    {
+        "CreatedAt": datetime,
+        "IsBatchStatement": bool,
+        "QueryParameters": List["SqlParameterTypeDef"],
+        "QueryString": str,
+        "QueryStrings": List[str],
+        "SecretArn": str,
+        "StatementName": str,
+        "Status": StatusStringType,
+        "UpdatedAt": datetime,
+    },
+    total=False,
+)
 
-SubStatementDataTypeDef = TypedDict(
-    "SubStatementDataTypeDef",
+
+class StatementDataTypeDef(_RequiredStatementDataTypeDef, _OptionalStatementDataTypeDef):
+    pass
+
+
+_RequiredSubStatementDataTypeDef = TypedDict(
+    "_RequiredSubStatementDataTypeDef",
     {
         "Id": str,
-        "CreatedAt": NotRequired[datetime],
-        "Duration": NotRequired[int],
-        "Error": NotRequired[str],
-        "HasResultSet": NotRequired[bool],
-        "QueryString": NotRequired[str],
-        "RedshiftQueryId": NotRequired[int],
-        "ResultRows": NotRequired[int],
-        "ResultSize": NotRequired[int],
-        "Status": NotRequired[StatementStatusStringType],
-        "UpdatedAt": NotRequired[datetime],
     },
 )
+_OptionalSubStatementDataTypeDef = TypedDict(
+    "_OptionalSubStatementDataTypeDef",
+    {
+        "CreatedAt": datetime,
+        "Duration": int,
+        "Error": str,
+        "HasResultSet": bool,
+        "QueryString": str,
+        "RedshiftQueryId": int,
+        "ResultRows": int,
+        "ResultSize": int,
+        "Status": StatementStatusStringType,
+        "UpdatedAt": datetime,
+    },
+    total=False,
+)
+
+
+class SubStatementDataTypeDef(_RequiredSubStatementDataTypeDef, _OptionalSubStatementDataTypeDef):
+    pass
+
 
 TableMemberTypeDef = TypedDict(
     "TableMemberTypeDef",
     {
-        "name": NotRequired[str],
-        "schema": NotRequired[str],
-        "type": NotRequired[str],
+        "name": str,
+        "schema": str,
+        "type": str,
     },
+    total=False,
 )
